@@ -11,8 +11,8 @@ import typing
 import pytest
 
 import attr
+import attrs
 
-from attr._compat import PY_3_14_PLUS
 from attr._make import _is_class_var
 from attr.exceptions import UnannotatedAttributeError
 
@@ -61,7 +61,7 @@ class TestAnnotations:
                 x: int = attr.ib(type=int)
 
         assert (
-            "Type annotation and type argument cannot both be present",
+            "Type annotation and type argument cannot both be present for 'x'.",
         ) == e.value.args
 
     def test_typing_annotations(self):
@@ -107,7 +107,7 @@ class TestAnnotations:
         class C:
             cls_var: typing.ClassVar[int] = 23
             a: int
-            x: typing.List[int] = attr.Factory(list)
+            x: typing.List[int] = attrs.Factory(list)
             y: int = 2
             z: int = attr.ib(default=3)
             foo: typing.Any = None
@@ -407,7 +407,7 @@ class TestAnnotations:
             cls_var2: "ClassVar[int]" = 23
             cls_var3: "t.ClassVar[int]" = 23
             a: "int"
-            x: "typing.List[int]" = attr.Factory(list)
+            x: "typing.List[int]" = attrs.Factory(list)
             y: "int" = 2
             z: "int" = attr.ib(default=3)
             foo: "typing.Any" = None
@@ -500,7 +500,7 @@ class TestAnnotations:
 
         @attr.s(auto_attribs=True)
         class C:
-            x: typing.Any = NonComparable()
+            x: typing.Any = NonComparable()  # noqa: RUF009
 
     def test_basic_resolve(self):
         """
@@ -587,8 +587,6 @@ class TestAnnotations:
         """
         References to self class using quotes can be resolved.
         """
-        if PY_3_14_PLUS and not slots:
-            pytest.xfail("References are changing a lot in 3.14.")
 
         @attr.s(slots=slots, auto_attribs=True)
         class A:
@@ -604,8 +602,6 @@ class TestAnnotations:
         """
         Forward references can be resolved.
         """
-        if PY_3_14_PLUS and not slots:
-            pytest.xfail("Forward references are changing a lot in 3.14.")
 
         @attr.s(slots=slots, auto_attribs=True)
         class A:
